@@ -1,5 +1,10 @@
 # example spcosa package: stratified simple random sampling
 
+# check if required packages are available
+if (suppressWarnings(!require(rgdal))) {
+    stop("This demo requires package 'rgdal'.\nThis package is currently not available. Please install 'rgdal' first.", call. = FALSE)
+}    
+
 # initialize pseudo random number generator
 set.seed(700124)
 
@@ -26,3 +31,4 @@ myData <- data.frame(observation = rnorm(n = 2, mean = 10, sd = 1))
 # design-based inference
 estimate("spatial mean",   myStratification, mySamplingPattern, myData)
 estimate("standard error", myStratification, mySamplingPattern, myData)
+
